==> gdm-2.21.2.tar.bz2: gdm-2.21.2/gui/simple-greeter/gdm-session-chooser-widget.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __GDM_SESSION_CHOOSER_WIDGET_H
#define __GDM_SESSION_CHOOSER_WIDGET_H

#include <glib-object.h>
#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GDM_TYPE_SESSION_CHOOSER_WIDGET         (gdm_session_chooser_widget_get_type ())
#define GDM_SESSION_CHOOSER_WIDGET(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidget))
#define GDM_SESSION_CHOOSER_WIDGET_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidgetClass))
#define GDM_IS_SESSION_CHOOSER_WIDGET(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET))
#define GDM_IS_SESSION_CHOOSER_WIDGET_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), GDM_TYPE_SESSION_CHOOSER_WIDGET))
#define GDM_SESSION_CHOOSER_WIDGET_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidgetClass))

typedef struct GdmSessionChooserWidgetPrivate GdmSessionChooserWidgetPrivate;

typedef struct
{
        GtkVBox                         parent;
        GdmSessionChooserWidgetPrivate *priv;
} GdmSessionChooserWidget;

typedef struct
{
        GtkVBoxClass   parent_class;

        /* signals */
        void (* session_activated)        (GdmSessionChooserWidget *widget);
} GdmSessionChooserWidgetClass;

GType                  gdm_session_chooser_widget_get_type                      (void);
GtkWidget *            gdm_session_chooser_widget_new                           (void);

char *                 gdm_session_chooser_widget_get_current_session_name      (GdmSessionChooserWidget *widget);
void                   gdm_session_chooser_widget_set_current_session_name      (GdmSessionChooserWidget *widget,
                                                                                 const char              *session_name);

G_END_DECLS

#endif /* __GDM_SESSION_CHOOSER_WIDGET_H */

==> gdm-2.21.6.tar.bz2: gdm-2.21.6/gui/simple-greeter/gdm-session-chooser-widget.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __GDM_SESSION_CHOOSER_WIDGET_H
#define __GDM_SESSION_CHOOSER_WIDGET_H

#include <glib-object.h>
#include "gdm-chooser-widget.h"

G_BEGIN_DECLS

#define GDM_TYPE_SESSION_CHOOSER_WIDGET         (gdm_session_chooser_widget_get_type ())
#define GDM_SESSION_CHOOSER_WIDGET(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidget))
#define GDM_SESSION_CHOOSER_WIDGET_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidgetClass))
#define GDM_IS_SESSION_CHOOSER_WIDGET(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET))
#define GDM_IS_SESSION_CHOOSER_WIDGET_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), GDM_TYPE_SESSION_CHOOSER_WIDGET))
#define GDM_SESSION_CHOOSER_WIDGET_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GDM_TYPE_SESSION_CHOOSER_WIDGET, GdmSessionChooserWidgetClass))

typedef struct GdmSessionChooserWidgetPrivate GdmSessionChooserWidgetPrivate;

typedef struct
{
        GdmChooserWidget                parent;
        GdmSessionChooserWidgetPrivate *priv;
} GdmSessionChooserWidget;

typedef struct
{
        GdmChooserWidgetClass   parent_class;
} GdmSessionChooserWidgetClass;

#define GDM_SESSION_CHOOSER_SESSION_PREVIOUS "__previous-session"
#define GDM_SESSION_CHOOSER_SESSION_DEFAULT "__default-session"

GType                  gdm_session_chooser_widget_get_type                      (void);
GtkWidget *            gdm_session_chooser_widget_new                           (void);

char *                 gdm_session_chooser_widget_get_current_session_name      (GdmSessionChooserWidget *widget);
void                   gdm_session_chooser_widget_set_current_session_name      (GdmSessionChooserWidget *widget,
                                                                                 const char              *session_name);
void                   gdm_session_chooser_widget_set_show_only_chosen          (GdmSessionChooserWidget *widget,
                                                                                 gboolean                 show_only);
G_END_DECLS

#endif /* __GDM_SESSION_CHOOSER_WIDGET_H */
